==> estateplat-common-1.1.0-20160727.070300-131-sources.jar: cn/gtmap/estateplat/model/server/core/GdLsLq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/27
 * @description 历史过渡林权
 */
@Table(name = "gd_ls_lq")
public class GdLsLq implements Serializable{
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主键
     */
    @Id
    private String lqid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林地共有情况
     */
    private String ldgyqk;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 使用权（承包）面积
     */
    private Double syqmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林地使用开始日期
     */
    private Date ldsyksrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林地使用结束日期
     */
    private Date ldsyjsrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林地所有权性质
     */
    private String ldsuqxz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主要树种
     */
    private String zysz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 株数
     */
    private Integer zs;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林种
     */
    private String lz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 造林年度
     */
    private String zlnd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 小地名
     */
    private String xdm;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林班
     */
    private String lb;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 小班
     */
    private String xb;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 起源
     */
    private String qy;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林权坐落
     */
    private String lqzl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林权证号
     */
    private String lqzh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 单位
     */
    private String dw;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 地籍号
     */
    private String djh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 数据来源
     */
    private String sjly;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林木使用权人
     */
    private String lmsyqr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林木所有权人
     */
    private String lmsuqr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 发包方名称
     */
    private String fbfmc;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 更新日期
     */
    private Date gxrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 单位代码
     */
    private String dwdm;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 项目ID
     */
    private String proid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 原产权证号
     */
    private String yqzh;

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public String getLqid() {
        return lqid;
    }

    public void setLqid(String lqid) {
        this.lqid = lqid;
    }

    public String getLdgyqk() {
        return ldgyqk;
    }

    public void setLdgyqk(String ldgyqk) {
        this.ldgyqk = ldgyqk;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public Date getLdsyksrq() {
        return ldsyksrq;
    }

    public void setLdsyksrq(Date ldsyksrq) {
        this.ldsyksrq = ldsyksrq;
    }

    public Date getLdsyjsrq() {
        return ldsyjsrq;
    }

    public void setLdsyjsrq(Date ldsyjsrq) {
        this.ldsyjsrq = ldsyjsrq;
    }

    public String getLdsuqxz() {
        return ldsuqxz;
    }

    public void setLdsuqxz(String ldsuqxz) {
        this.ldsuqxz = ldsuqxz;
    }

    public String getZysz() {
        return zysz;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public Integer getZs() {
        return zs;
    }

    public void setZs(Integer zs) {
        this.zs = zs;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getZlnd() {
        return zlnd;
    }

    public void setZlnd(String zlnd) {
        this.zlnd = zlnd;
    }

    public String getXdm() {
        return xdm;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getQy() {
        return qy;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public String getLqzl() {
        return lqzl;
    }

    public void setLqzl(String lqzl) {
        this.lqzl = lqzl;
    }

    public String getLqzh() {
        return lqzh;
    }

    public void setLqzh(String lqzh) {
        this.lqzh = lqzh;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }


    public String getLmsyqr() {
        return lmsyqr;
    }

    public void setLmsyqr(String lmsyqr) {
        this.lmsyqr = lmsyqr;
    }

    public String getLmsuqr() {
        return lmsuqr;
    }

    public void setLmsuqr(String lmsuqr) {
        this.lmsuqr = lmsuqr;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }


}

==> estateplat-common-1.2.3-20180917.054516-185-sources.jar: cn/gtmap/estateplat/model/server/core/GdLsLq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/27
 * @description 历史过渡林权
 */
@Table(name = "gd_ls_lq")
public class GdLsLq implements Serializable{
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主键
     */
    @Id
    private String lqid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林地共有情况
     */
    private String ldgyqk;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 使用权（承包）面积
     */
    private Double syqmj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林地使用开始日期
     */
    private Date ldsyksrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林地使用结束日期
     */
    private Date ldsyjsrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林地所有权性质
     */
    private String ldsuqxz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主要树种
     */
    private String zysz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 株数
     */
    private Integer zs;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林种
     */
    private String lz;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 造林年度
     */
    private String zlnd;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 小地名
     */
    private String xdm;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林班
     */
    private String lb;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 小班
     */
    private String xb;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 起源
     */
    private String qy;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林权坐落
     */
    private String lqzl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林权证号
     */
    private String lqzh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 面积单位
     */
    private String mjdw;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 地籍号
     */
    private String djh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林木使用权人
     */
    private String lmsyqr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 林木所有权人
     */
    private String lmsuqr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 发包方名称
     */
    private String fbfmc;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 单位代码
     */
    private String dwdm;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 项目ID
     */
    private String proid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 登簿人
     */
    private String dbr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 登记时间
     */
    private Date djsj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 档案业务号
     */
    private String daywh;

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getLqid() {
        return lqid;
    }

    public void setLqid(String lqid) {
        this.lqid = lqid;
    }

    public String getLdgyqk() {
        return ldgyqk;
    }

    public void setLdgyqk(String ldgyqk) {
        this.ldgyqk = ldgyqk;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public Date getLdsyksrq() {
        return ldsyksrq;
    }

    public void setLdsyksrq(Date ldsyksrq) {
        this.ldsyksrq = ldsyksrq;
    }

    public Date getLdsyjsrq() {
        return ldsyjsrq;
    }

    public void setLdsyjsrq(Date ldsyjsrq) {
        this.ldsyjsrq = ldsyjsrq;
    }

    public String getLdsuqxz() {
        return ldsuqxz;
    }

    public void setLdsuqxz(String ldsuqxz) {
        this.ldsuqxz = ldsuqxz;
    }

    public String getZysz() {
        return zysz;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public Integer getZs() {
        return zs;
    }

    public void setZs(Integer zs) {
        this.zs = zs;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getZlnd() {
        return zlnd;
    }

    public void setZlnd(String zlnd) {
        this.zlnd = zlnd;
    }

    public String getXdm() {
        return xdm;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getQy() {
        return qy;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public String getLqzl() {
        return lqzl;
    }

    public void setLqzl(String lqzl) {
        this.lqzl = lqzl;
    }

    public String getLqzh() {
        return lqzh;
    }

    public void setLqzh(String lqzh) {
        this.lqzh = lqzh;
    }

    public String getLmsyqr() {
        return lmsyqr;
    }

    public void setLmsyqr(String lmsyqr) {
        this.lmsyqr = lmsyqr;
    }

    public String getLmsuqr() {
        return lmsuqr;
    }

    public void setLmsuqr(String lmsuqr) {
        this.lmsuqr = lmsuqr;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }


    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDaywh() {
        return daywh;
    }

    public void setDaywh(String daywh) {
        this.daywh = daywh;
    }
}
